@@ -1,7 +1,6 @@
 #!/usr/bin/perl -w
 
 use strict;
-use IPC::Run qw(run);
 $| = 1;
 
 print "Attempting to make all tests...\n";
@@ -10,7 +9,7 @@ my($in, $out, $err);
 
 foreach my $file (sort <*.data.in>) {
   print "  Running $file...";
-  run ["/usr/bin/perl ./build_test @ARGV ./$file"], \$in, \$out, \$err; 
+  system "/usr/bin/perl ./build_test ./$file @ARGV";
   print "done\n";
 }
 
